summaryrefslogtreecommitdiffstats
path: root/src/H5Dio.c
diff options
context:
space:
mode:
authorDana Robinson <derobins@hdfgroup.org>2018-04-30 22:15:14 (GMT)
committerDana Robinson <derobins@hdfgroup.org>2018-04-30 22:15:14 (GMT)
commit3313fde3bb8b6cc5cfa3c8401615ac064f7cbdf9 (patch)
treebbac1d3d45ea47d8ae817726f3552ef48a82ab2b /src/H5Dio.c
parent4fe4394c5856336345efd2e7293d703c9bfc6d1b (diff)
downloadhdf5-3313fde3bb8b6cc5cfa3c8401615ac064f7cbdf9.zip
hdf5-3313fde3bb8b6cc5cfa3c8401615ac064f7cbdf9.tar.gz
hdf5-3313fde3bb8b6cc5cfa3c8401615ac064f7cbdf9.tar.bz2
Normalize with trunk prior to update merge
Diffstat (limited to 'src/H5Dio.c')
-rw-r--r--src/H5Dio.c32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/H5Dio.c b/src/H5Dio.c
index b1117e9..1447f99 100644
--- a/src/H5Dio.c
+++ b/src/H5Dio.c
@@ -90,14 +90,14 @@ H5FL_DEFINE(H5D_chunk_map_t);
* passed to this function with the PLIST_ID argument.
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
* that the entire file data space is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
* the memory data space is the same as the file data space
* defined when the dataset was created.
*
* The number of elements in the memory data space must match
* the number of elements in the file data space.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
* case the default data transfer properties are used.
@@ -135,7 +135,7 @@ H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id,
/* Check dataspaces */
if (H5S_ALL != mem_space_id) {
if (NULL == (mem_space = (const H5S_t *)H5I_object_verify(mem_space_id, H5I_DATASPACE)))
- HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data space")
+ HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
/* Check for valid selection */
if (H5S_SELECT_VALID(mem_space) != TRUE)
@@ -143,7 +143,7 @@ H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id,
}
if (H5S_ALL != file_space_id) {
if (NULL == (file_space = (const H5S_t *)H5I_object_verify(file_space_id, H5I_DATASPACE)))
- HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data space")
+ HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
/* Check for valid selection */
if (H5S_SELECT_VALID(file_space) != TRUE)
@@ -257,14 +257,14 @@ done:
* PLIST_ID argument.
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
* that the entire file data space is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
* the memory data space is the same as the file data space
* defined when the dataset was created.
*
* The number of elements in the memory data space must match
* the number of elements in the file data space.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
* case the default data transfer properties are used.
@@ -441,7 +441,7 @@ H5D__read(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
hbool_t type_info_init = FALSE; /* Whether the datatype info has been initialized */
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
/* data space with rank equal to that of */
/* file_space. */
/* */
/* This field is only used if */
@@ -494,7 +494,7 @@ H5D__read(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
/* Make certain that the number of elements in each selection is the same */
if(nelmts != (hsize_t)H5S_GET_SELECT_NPOINTS(file_space))
- HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest data spaces have different sizes")
+ HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest dataspaces have different sizes")
/* Check for a NULL buffer, after the H5S_ALL dataspace selection has been handled */
if(NULL == buf) {
@@ -653,7 +653,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
hbool_t type_info_init = FALSE; /* Whether the datatype info has been initialized */
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
/* data space with rank equal to that of */
/* file_space. */
/* */
/* This field is only used if */
@@ -737,7 +737,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
/* Make certain that the number of elements in each selection is the same */
if(nelmts != (hsize_t)H5S_GET_SELECT_NPOINTS(file_space))
- HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest data spaces have different sizes")
+ HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest dataspaces have different sizes")
/* Check for a NULL buffer, after the H5S_ALL dataspace selection has been handled */
if(NULL == buf) {
@@ -797,7 +797,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
if(H5D__ioinfo_init(dataset, &type_info, &store, &io_info) < 0)
HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to set up I/O operation")
/* Allocate data space and initialize it if it hasn't been. */
if(nelmts > 0 && dataset->shared->dcpl_cache.efl.nused == 0 &&
!(*dataset->shared->layout.ops->is_space_alloc)(&dataset->shared->layout.storage)) {
hssize_t file_nelmts; /* Number of elements in file dataset's dataspace */
@@ -992,7 +992,7 @@ H5D__typeinfo_init(const H5D_t *dset, hid_t mem_type_id, hbool_t do_write,
} /* end else */
/*
* Locate the type conversion function and data space conversion
* functions, and set up the element numbering information. If a data
* type conversion is necessary then register datatype atoms. Data type
* conversion is necessary if the user has set the `need_bkg' to a high
@@ -90,14 +90,14 @@ H5FL_DEFINE(H5D_chunk_map_t);
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
- * that the entire file data space is to be referenced.
+ * that the entire file dataspace is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
@@ -90,14 +90,14 @@ H5FL_DEFINE(H5D_chunk_map_t);
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
- * the memory data space is the same as the file data space
+ * the memory dataspace is the same as the file dataspace
* defined when the dataset was created.
*
@@ -90,14 +90,14 @@ H5FL_DEFINE(H5D_chunk_map_t);
* defined when the dataset was created.
*
- * The number of elements in the memory data space must match
- * the number of elements in the file data space.
+ * The number of elements in the memory dataspace must match
+ * the number of elements in the file dataspace.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
@@ -257,14 +257,14 @@ done:
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
- * that the entire file data space is to be referenced.
+ * that the entire file dataspace is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
@@ -257,14 +257,14 @@ done:
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
- * the memory data space is the same as the file data space
+ * the memory dataspace is the same as the file dataspace
* defined when the dataset was created.
*
@@ -257,14 +257,14 @@ done:
* defined when the dataset was created.
*
- * The number of elements in the memory data space must match
- * the number of elements in the file data space.
+ * The number of elements in the memory dataspace must match
+ * the number of elements in the file dataspace.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
@@ -441,7 +441,7 @@ H5D__read(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
- /* data space with rank equal to that of */
+ /* dataspace with rank equal to that of */
/* file_space. */
/* */
@@ -653,7 +653,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
- /* data space with rank equal to that of */
+ /* dataspace with rank equal to that of */
/* file_space. */
/* */
@@ -797,7 +797,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
if(H5D__ioinfo_init(dataset, &type_info, &store, &io_info) < 0)
HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to set up I/O operation")
- /* Allocate data space and initialize it if it hasn't been. */
+ /* Allocate dataspace and initialize it if it hasn't been. */
if(nelmts > 0 && dataset->shared->dcpl_cache.efl.nused == 0 &&
!(*dataset->shared->layout.ops->is_space_alloc)(&dataset->shared->layout.storage)) {
@@ -992,7 +992,7 @@ H5D__typeinfo_init(const H5D_t *dset, hid_t mem_type_id, hbool_t do_write,
} /* end else */
/*
- * Locate the type conversion function and data space conversion
+ * Locate the type conversion function and dataspace conversion
* functions, and set up the element numbering information. If a data
* type conversion is necessary then register datatype atoms. Data type